@@ -57,6 +57,15 @@ def seq(instr=None) -> list:
 
 
 def expand_macro(prim, annots, args, internal=False, extra=None):
+    """ Expands Michelson macro.
+
+    :param prim: macro name
+    :param annots: annotations (optional)
+    :param args: arguments (optional)
+    :param internal: this function is called during another mocro expansion
+    :param extra: list of ignored primitives
+    :returns: Code sequence (Micheline expression)
+    """
     assert isinstance(annots, list)
     assert isinstance(args, list)
     if prim in primitives or (isinstance(extra, list) and prim in extra):
@@ -276,6 +285,13 @@ def expand_if_some(prim, annots, args) -> dict:
     return expr(prim='IF_NONE', args=list(reversed(args)))
 
 
+@macro(r'^IF_RIGHT$')
+def expand_if_right(prim, annots, args) -> dict:
+    assert not annots
+    assert len(args) == 2
+    return expr(prim='IF_LEFT', args=list(reversed(args)))
+
+
 @macro(r'^SET_CAR$')
 def expand_set_car(prim, annots, args) -> list:
     assert not args
